Dapr flask extension
====================

|pypi|

.. |pypi| image:: https://badge.fury.io/py/flask-dapr.svg
   :target: https://pypi.org/project/flask-dapr/

This flask extension is used to run actor service.

Installation
------------

::

    pip install flask-dapr

References
----------

* `Dapr <https://github.com/dapr/dapr>`_
* `Dapr Python-SDK <https://github.com/dapr/python-sdk>`_
